==> brkout-0.1.tar.gz: brkout-0.1/environ-dc.sh <==
# KallistiOS environment variable settings
# This is a sample script; the 'configure' program can produce a full
#   script for you, but that's assuming that 'cdialog' works on your
#   system. If not, you may want to edit this script (for Bash) or 
#   environ.tcsh (for TCSH) and use that.
# This script is for the DC configuation only!
# $Id: environ-dc.sh,v 1.2 2002/03/12 20:02:19 jim Exp $

# Build architecture
export KOS_ARCH="dreamcast"

# KOS base paths
export KOS_BASE="/home/jim/dc/kos/kos"
export KOS_INCS="${KOS_BASE}/include"

# Make utility
export KOS_MAKE="make"

# Load utility
export KOS_LOADER="${KOS_BASE}/utils/ipload/ipload.py"

# Genromfs utility
export KOS_GENROMFS="${KOS_BASE}/utils/genromfs/genromfs"

# SH-4 GCC paths
export KOS_CC_BASE="/usr/local/dc-0312/sh-elf"
export KOS_CC="${KOS_CC_BASE}/bin/sh-elf-gcc"
# export KOS_CCPLUS="${KOS_CC_BASE}/bin/sh-elf-g++"
export KOS_AS="${KOS_CC_BASE}/bin/sh-elf-as"
export KOS_AR="${KOS_CC_BASE}/bin/sh-elf-ar"
export KOS_OBJCOPY="${KOS_CC_BASE}/bin/sh-elf-objcopy"
export KOS_LD="${KOS_CC_BASE}/bin/sh-elf-ld"
export KOS_CFLAGS="-Wall -ml -m4-single-only -O -fno-builtin -fno-strict-aliasing -fomit-frame-pointer"
# export KOS_CFLAGS="-Wall -ml -m4-single-only -O3 -fno-builtin -fno-strict-aliasing -fomit-frame-pointer -fschedule-insns -fschedule-insns2 -frename-registers -fssa"
export KOS_CPPFLAGS="-fno-operator-names -fno-rtti"
export KOS_AFLAGS="-little"
export KOS_LDFLAGS="-ml -m4-single-only -nostartfiles -nostdlib -Wl,-Ttext=0x8c010000"

# ARM7 GCC paths
export DC_ARM7BASE="/usr/local/dc/arm-elf"
export DC_ARM7CC="${DC_ARM7BASE}/bin/arm-elf-gcc"
export DC_ARM7AS="${DC_ARM7BASE}/bin/arm-elf-as"
export DC_ARM7AR="${DC_ARM7BASE}/bin/arm-elf-ar"
export DC_ARM7OBJCOPY="${DC_ARM7BASE}/bin/arm-elf-objcopy"
export DC_ARM7LD="${DC_ARM7BASE}/bin/arm-elf-ld"
export DC_ARM7CFLAGS="-mcpu=arm7 -Wall -O2"
export DC_ARM7AFLAGS="-marm7"

==> brkout-0.1.1.tar.gz: brkout-0.1.1/environ-dc.sh <==
# KallistiOS environment variable settings
# This is a sample script; the 'configure' program can produce a full
#   script for you, but that's assuming that 'cdialog' works on your
#   system. If not, you may want to edit this script (for Bash) or 
#   environ.tcsh (for TCSH) and use that.
# This script is for the DC configuation only!
# $Id: environ-dc.sh,v 1.2 2001/12/04 06:59:55 jim Exp $

# Build architecture
export KOS_ARCH="dreamcast"

# KOS base paths
export KOS_BASE="/home/jim/dc/kos/kos"
export KOS_INCS="${KOS_BASE}/include"

# Make utility
export KOS_MAKE="make"

# Load utility
export KOS_LOADER="${KOS_BASE}/utils/ipload/ipload.py"

# Genromfs utility
export KOS_GENROMFS="${KOS_BASE}/utils/genromfs/genromfs"

# SH-4 GCC paths
export KOS_CC_BASE="/usr/local/dc/sh-elf"
# export KOS_CC_BASE="/usr/local/dc-0312/sh-elf"
export KOS_CC="${KOS_CC_BASE}/bin/sh-elf-gcc"
# export KOS_CCPLUS="${KOS_CC_BASE}/bin/sh-elf-g++"
export KOS_AS="${KOS_CC_BASE}/bin/sh-elf-as"
export KOS_AR="${KOS_CC_BASE}/bin/sh-elf-ar"
export KOS_OBJCOPY="${KOS_CC_BASE}/bin/sh-elf-objcopy"
export KOS_LD="${KOS_CC_BASE}/bin/sh-elf-ld"
export KOS_CFLAGS="-Wall -ml -m4-single-only -O2 -fno-builtin -fno-strict-aliasing -fomit-frame-pointer -fno-optimize-sibling-calls"
# export KOS_CFLAGS="-Wall -ml -m4-single-only -O3 -fno-builtin -fno-strict-aliasing -fomit-frame-pointer -fschedule-insns -fschedule-insns2 -frename-registers -fssa"
export KOS_CPPFLAGS="-fno-operator-names -fno-rtti"
export KOS_AFLAGS="-little"
export KOS_LDFLAGS="-ml -m4-single-only -nostartfiles -nostdlib -Wl,-Ttext=0x8c010000"

# ARM7 GCC paths
export DC_ARM7BASE="/usr/local/dc/arm-elf"
export DC_ARM7CC="${DC_ARM7BASE}/bin/arm-elf-gcc"
export DC_ARM7AS="${DC_ARM7BASE}/bin/arm-elf-as"
export DC_ARM7AR="${DC_ARM7BASE}/bin/arm-elf-ar"
export DC_ARM7OBJCOPY="${DC_ARM7BASE}/bin/arm-elf-objcopy"
export DC_ARM7LD="${DC_ARM7BASE}/bin/arm-elf-ld"
export DC_ARM7CFLAGS="-mcpu=arm7 -Wall -O2"
export DC_ARM7AFLAGS="-marm7"
